@@ -689,7 +689,7 @@ class CloudPods:
                 "OverridePendingDelete": True
             }
             rs = self.__session.delete(url=url,params=params, verify=False, timeout=600)
-            if rs.status_code == 200:
+            if rs.status_code == 200 or rs.status_code == 404:
                 log.info(f"server {server_id} has been deleted")
                 return True
             else:
